Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.net4j/src')
-rw-r--r--plugins/org.eclipse.net4j/src/org/eclipse/net4j/buffer/BufferState.java6
-rw-r--r--plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorLocation.java8
-rw-r--r--plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorState.java36
-rw-r--r--plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/IConnector.java4
-rw-r--r--plugins/org.eclipse.net4j/src/org/eclipse/net4j/package.html8
5 files changed, 32 insertions, 30 deletions
diff --git a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/buffer/BufferState.java b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/buffer/BufferState.java
index d01c7daa8a..870beb0df0 100644
--- a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/buffer/BufferState.java
+++ b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/buffer/BufferState.java
@@ -34,9 +34,9 @@ public enum BufferState
* and subsequently {@link IBuffer#clear() cleared}.
* <p>
* A transition to {@link #PUTTING} can be triggered by calling {@link IBuffer#startPutting(short)} once. If the
- * buffer is intended to be passed to an {@link IChannel} later the {@link IChannel#getChannelIndex() channel index}
- * of that Channel has to be passed because it is part of the buffer's header. A {@link ByteBuffer} is returned that
- * can be used for putting data.
+ * buffer is intended to be passed to an {@link org.eclipse.net4j.channel.IChannel IChannel} later the
+ * {@link org.eclipse.net4j.channel.IChannel#getChannelIndex() channel index} of that Channel has to be passed because
+ * it is part of the buffer's header. A {@link ByteBuffer} is returned that can be used for putting data.
* <p>
* A transition to {@link #GETTING} can be triggered by calling {@link IBuffer#startGetting(SocketChannel)} repeatedly
* until it finally returns a {@link ByteBuffer} that can be used for getting data.
diff --git a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorLocation.java b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorLocation.java
index e2f8139eea..b1125698b1 100644
--- a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorLocation.java
+++ b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorLocation.java
@@ -10,8 +10,8 @@
**************************************************************************/
package org.eclipse.net4j.connector;
-import org.eclipse.net4j.acceptor.IAcceptor;
import org.eclipse.net4j.buffer.IBuffer;
+import org.eclipse.net4j.buffer.IBufferHandler;
import org.eclipse.net4j.channel.IChannel;
import org.eclipse.net4j.protocol.IProtocol;
@@ -19,8 +19,8 @@ import org.eclipse.net4j.protocol.IProtocol;
* Enumerates the roles that an {@link IConnector} can play during the establishment of a physical connection.
* <p>
* An active connector that is created by a client application plays a {@link #CLIENT} role and a passive connector that
- * is created by an {@link IAcceptor} in response to a call to one of the active connector's connect methods plays a
- * {@link #SERVER} role.
+ * is created by an {@link org.eclipse.net4j.acceptor.IAcceptor IAcceptor} in response to a call to one of the active
+ * connector's connect methods plays a {@link #SERVER} role.
* <p>
* Note however that the role of a connector is only meaningful to determine how a physical connection has been
* <em>established</em>. Once it has been established actual communication (opening {@link IChannel}s, sending and
@@ -31,7 +31,7 @@ import org.eclipse.net4j.protocol.IProtocol;
* @see IConnector#connectAsync()
* @see IConnector#openChannel()
* @see IConnector#openChannel(IProtocol)
- * @see IConnector#openChannel(String)
+ * @see IConnector#openChannel(String, Object)
* @see IChannel#sendBuffer(IBuffer)
* @see IChannel#setReceiveHandler(IBufferHandler)
* @author Eike Stepper
diff --git a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/IConnector.java b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/IConnector.java
index 13cd67c98d..9a928db8fb 100644
--- a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/IConnector.java
+++ b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/IConnector.java
@@ -138,7 +138,7 @@ public interface IConnector extends IContainer<IChannel>
* {@link IListener listeners}.
* <p>
*
- * @see #openChannel(String)
+ * @see #openChannel(String, Object)
* @see #openChannel(IProtocol)
*/
public IChannel openChannel() throws ConnectorException;
@@ -161,7 +161,7 @@ public interface IConnector extends IContainer<IChannel>
* <p>
*
* @see #openChannel()
- * @see #openChannel(String)
+ * @see #openChannel(String, Object)
*/
public IChannel openChannel(IProtocol protocol) throws ConnectorException;
}
diff --git a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/package.html b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/package.html
index 7f6b8f7b5c..8e8f36f4bd 100644
--- a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/package.html
+++ b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/package.html
@@ -18,10 +18,10 @@
The Net4j transport layer.
The four main interfaces of the transport layer are
-{@link org.eclipse.net4j.transport.IBuffer},
-{@link org.eclipse.net4j.transport.IChannel},
-{@link org.eclipse.net4j.transport.IConnector} and
-{@link org.eclipse.net4j.transport.IProtocol}.
+{@link org.eclipse.net4j.buffer.IBuffer},
+{@link org.eclipse.net4j.channel.IChannel},
+{@link org.eclipse.net4j.connector.IConnector} and
+{@link org.eclipse.net4j.protocol.IProtocol}.
<p>
<dt><b>Sequence Diagram: Communication Process</b></dt>

Back to the top
diff --git a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorState.java b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorState.java
index 59b9b70760..f42e5360ae 100644
--- a/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorState.java
+++ b/plugins/org.eclipse.net4j/src/org/eclipse/net4j/connector/ConnectorState.java
@@ -10,8 +10,7 @@
**************************************************************************/
package org.eclipse.net4j.connector;
-import org.eclipse.net4j.util.lifecycle.ILifecycle;
-import org.eclipse.net4j.util.lifecycle.LifecycleUtil;
+import org.eclipse.net4j.util.security.INegotiator;
/**
* Enumerates the lifecycle states of an {@link IConnector}.
@@ -37,12 +36,13 @@ public enum ConnectorState
* Indicates that the {@link IConnector} has not been connected yet or has been disconnected after being connected
* previously.
* <p>
- * A connector is <code>DISCONNECTED</code> if and only if it is not {@link LifecycleUtil#isActive(Object) active}.
- * A transition to {@link #CONNECTING} can be triggered by calling {@link IConnector#connect(long)} or
+ * A connector is <code>DISCONNECTED</code> if and only if it is not
+ * {@link org.eclipse.net4j.util.lifecycle.LifecycleUtil#isActive(Object) active}. A transition to
+ * {@link #CONNECTING} can be triggered by calling {@link IConnector#connect(long)} or
* {@link IConnector#connectAsync()}.
*
* @see IConnector#getState()
- * @see ILifecycle.Introspection#isActive()
+ * @see org.eclipse.net4j.util.lifecycle.ILifecycle.Introspection#isActive()
*/
DISCONNECTED,
@@ -50,29 +50,30 @@ public enum ConnectorState
* Indicates that the {@link IConnector} is currently trying to establish an underlying physical connection like a TCP
* socket connection.
* <p>
- * A connector can only be <code>CONNECTING</code> if it is {@link LifecycleUtil#isActive(Object) active}. As soon
- * as the underlying physical connection is successfully established the state of the connector automatically
- * transitions to {@link #NEGOTIATING}.
+ * A connector can only be <code>CONNECTING</code> if it is
+ * {@link org.eclipse.net4j.util.lifecycle.LifecycleUtil#isActive(Object) active}. As soon as the underlying physical
+ * connection is successfully established the state of the connector automatically transitions to {@link #NEGOTIATING}.
*
* @see IConnector#getState()
- * @see ILifecycle.Introspection#isActive()
+ * @see org.eclipse.net4j.util.lifecycle.ILifecycle.Introspection#isActive()
*/
CONNECTING,
/**
* Indicates that the {@link IConnector} has successfully managed to establish the underlying physical connection and
* has currently delegated control over this connection to an {@link IConnectorNegotiator}.
* <p>
- * A connector can only be <code>NEGOTIATING</code> if it is {@link LifecycleUtil#isActive(Object) active} and a
- * negotiator has been supplied. As soon as the negotiator has successfully negotiated both peers (or a negotiator has
- * not been supplied) the state of the connector automatically transitions to {@link #CONNECTED}.
+ * A connector can only be <code>NEGOTIATING</code> if it is
+ * {@link org.eclipse.net4j.util.lifecycle.LifecycleUtil#isActive(Object) active} and a negotiator has been supplied.
+ * As soon as the negotiator has successfully negotiated both peers (or a negotiator has not been supplied) the state
+ * of the connector automatically transitions to {@link #CONNECTED}.
* <p>
* Negotiators can implement arbitrary handshake protocols, challenge-response sequences or other authentication
* procedures. They can also be used to initially setup connection encryption if the connector implementation is not
* able to do so.
*
* @see IConnector#getState()
- * @see ILifecycle.Introspection#isActive()
+ * @see org.eclipse.net4j.util.lifecycle.ILifecycle.Introspection#isActive()
*/
NEGOTIATING,
@@ -80,11 +81,12 @@ public enum ConnectorState
* Indicates that the {@link IConnector} has successfully managed to establish and negotiate the underlying physical
* connection and is ready now to perform actual communications.
* <p>
- * A connector can only be <code>CONNECTED</code> if it is {@link LifecycleUtil#isActive(Object) active}. A
- * transition to {@link #DISCONNECTED} can be triggered by calling {@link IConnector#disconnect()}.
+ * A connector can only be <code>CONNECTED</code> if it is
+ * {@link org.eclipse.net4j.util.lifecycle.LifecycleUtil#isActive(Object) active}. A transition to
+ * {@link #DISCONNECTED} can be triggered by calling {@link IConnector#disconnect()}.
*
* @see IConnector#getState()
- * @see ILifecycle.Introspection#isActive()
+ * @see org.eclipse.net4j.util.lifecycle.ILifecycle.Introspection#isActive()
*/
CONNECTED
}
@@ -50,29 +50,30 @@ public enum ConnectorState
/**
* Indicates that the {@link IConnector} has successfully managed to establish the underlying physical connection and
- * has currently delegated control over this connection to an {@link IConnectorNegotiator}.
+ * has currently delegated control over this connection to an {@link INegotiator}.
* <p>